#' gdepoch
#' 
#' @keywords internal
#' 
#' @description Run a gradient descent epoch (L and R are starting points, 
#' gamma is stgammaize)
#' 
#' @return a list containing two matrices generated by the gradient descent for 
#' the current epoch
gdepoch <- function(L, R, lambda, gamma, nnzis , nnzjs, is, js, D, 
                    error_matrix = NULL) {
    ## create gradient matrices
    dL <- matrix(0, nrow = nrow(L), ncol = ncol(L))
    dR <- matrix(0, nrow = nrow(R), ncol = ncol(R))
    
    if(is.null(error_matrix)){
        error_matrix <- (D - L %*% R)
    }
    
    ## fill the gradient matrices using repeated calls to
    ## dlossp function
    for (i in seq_len(length(is))) {
        lossTmp <- dlossp(Li = L[is[i], ],
                          Rj = R[, js[i]],
                          nnzi = nnzis[is[i]],
                          nnzj = nnzjs[js[i]],
                          lambda = lambda,
                          error = error_matrix[is[i], js[i]] )

        dL[is[i], ] <- dL[is[i], ] + lossTmp$Li
        dR[, js[i]] <- dR[, js[i]] + lossTmp$Rj
    }
    
    ## perform a gradient step on L and R with step size gamma
    ## by using the gradient matrices
    
    #print(L - gamma * t(-2.0 * as.vector(R) %*% t(error_matrix) + 2.0 * lambda * as.vector(L)/nnzis))
    #print(as.vector(R) * t(error_matrix))
    
    #print(R - gamma * (-2.0 * as.vector(L) %*% (D - L %*% R) + 2.0 * lambda * as.vector(R)/nnzjs))
    
    L <- L - gamma * dL
    R <- R - gamma * dR
    
    ## return result
    return(list(L=L, R=R))
}